package xhttp3.internal.tls;

import java.security.GeneralSecurityException;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.net.ssl.SSLPeerUnverifiedException;

public final class BasicCertificateChainCleaner extends CertificateChainCleaner {
   private static final int MAX_SIGNERS = 9;
   private final TrustRootIndex trustRootIndex;

   public BasicCertificateChainCleaner(TrustRootIndex trustRootIndex) {
      this.trustRootIndex = trustRootIndex;
   }

   private boolean verifySignature(X509Certificate toVerify, X509Certificate signingCert) {
      if (!toVerify.getIssuerDN().equals(signingCert.getSubjectDN())) {
         return false;
      } else {
         try {
            toVerify.verify(signingCert.getPublicKey());
            return true;
         } catch (GeneralSecurityException var3) {
            return false;
         }
      }
   }

   public List<Certificate> clean(List<Certificate> chain, String hostname) {
      ArrayDeque hostname1;
      hostname1 = new ArrayDeque.<init>(chain);
      ArrayList chain1;
      ArrayList var10000 = chain1 = new ArrayList;
      chain1.<init>();
      var10000.add((Certificate)hostname1.removeFirst());
      boolean var3 = false;

      for(int var4 = 0; var4 < 9; ++var4) {
         X509Certificate var5 = (X509Certificate)chain1.get(chain1.size() - 1);
         X509Certificate var6;
         if ((var6 = this.trustRootIndex.findByIssuerAndSignature(var5)) == null) {
            Iterator var10 = hostname1.iterator();

            X509Certificate var7;
            do {
               if (!var10.hasNext()) {
                  if (var3) {
                     return chain1;
                  }

                  throw new SSLPeerUnverifiedException("Failed to find a trusted cert that signed " + var5);
               }
            } while(!this.verifySignature(var5, var7 = (X509Certificate)var10.next()));

            var10.remove();
            chain1.add(var7);
         } else {
            if (chain1.size() > 1 || !var5.equals(var6)) {
               chain1.add(var6);
            }

            if (this.verifySignature(var6, var6)) {
               return chain1;
            }

            var3 = true;
         }
      }

      throw new SSLPeerUnverifiedException("Certificate chain too long: " + chain1);
   }
}
